@@ -6,6 +6,7 @@ module Stackctl.FilterOption
   , filterOption
   , filterOptionFromPaths
   , filterOptionFromText
+  , filterOptionToPaths
   , filterStackSpecs
   ) where
 
@@ -37,12 +38,14 @@ instance HasFilterOption FilterOption where
   filterOptionL = id
 
 envFilterOption :: String -> Env.Parser Env.Error FilterOption
-envFilterOption items =
-  Env.var (first Env.UnreadError . readFilterOption) "FILTERS"
-    $ Env.help
-    $ "Filter "
-    <> items
-    <> " by patterns"
+envFilterOption items = var "FILTERS" <|> var "FILTER"
+ where
+  var name =
+    Env.var (first Env.UnreadError . readFilterOption) name
+      $ Env.help
+      $ "Filter "
+      <> items
+      <> " by patterns"
 
 filterOption :: String -> Parser FilterOption
 filterOption items = option (eitherReader readFilterOption) $ mconcat
@@ -93,6 +96,9 @@ showFilterOption =
 defaultFilterOption :: FilterOption
 defaultFilterOption = filterOptionFromPaths $ pure "**/*"
 
+filterOptionToPaths :: FilterOption -> [FilePath]
+filterOptionToPaths = map decompile . NE.toList . unFilterOption
+
 filterStackSpecs :: FilterOption -> [StackSpec] -> [StackSpec]
 filterStackSpecs fo =
   filter $ \spec -> any (`matchStackSpec` spec) $ unFilterOption fo
