@@ -1,6 +1,7 @@
 module Stackctl.Prelude
   ( module X
   , decodeUtf8
+  , maybeLens
   ) where
 
 import RIO as X hiding
@@ -26,7 +27,10 @@ import System.FilePath as X
   (dropExtension, takeBaseName, takeDirectory, (<.>), (</>))
 import UnliftIO.Directory as X (withCurrentDirectory)
 
-{-# ANN module ("HLint: ignore Avoid restricted qualification" :: String) #-}
+{-# ANN module ("HLint: ignore Avoid restricted alias" :: String) #-}
 
 decodeUtf8 :: ByteString -> Text
 decodeUtf8 = decodeUtf8With lenientDecode
+
+maybeLens :: a -> Lens' (Maybe a) a
+maybeLens x = lens (fromMaybe x) $ const Just
