@@ -20,6 +20,7 @@ import Stackctl.DirectoryOption (HasDirectoryOption)
 import Stackctl.FilterOption (HasFilterOption)
 import Stackctl.ParameterOption
 import Stackctl.Prompt
+import Stackctl.RemovedStack
 import Stackctl.Spec.Changes.Format
 import Stackctl.Spec.Discover
 import Stackctl.StackSpec
@@ -31,6 +32,7 @@ data DeployOptions = DeployOptions
   , sdoTags :: [Tag]
   , sdoSaveChangeSets :: Maybe FilePath
   , sdoDeployConfirmation :: DeployConfirmation
+  , sdoRemovals :: Bool
   , sdoClean :: Bool
   }
 
@@ -50,6 +52,10 @@ parseDeployOptions = DeployOptions
     (  long "no-confirm"
     <> help "Don't confirm changes before executing"
     )
+  <*> (not <$> switch
+    (  long "no-remove"
+    <> help "Don't delete removed Stacks"
+    ))
   <*> switch
     (  long "clean"
     <> help "Remove all changesets from Stack after deploy"
@@ -75,7 +81,8 @@ runDeploy DeployOptions {..} = do
 
   for_ specs $ \spec -> do
     withThreadContext ["stackName" .= stackSpecStackName spec] $ do
-      handleRollbackComplete sdoDeployConfirmation $ stackSpecStackName spec
+      checkIfStackRequiresDeletion sdoDeployConfirmation
+        $ stackSpecStackName spec
 
       emChangeSet <- createChangeSet spec sdoParameters sdoTags
 
@@ -97,12 +104,41 @@ runDeploy DeployOptions {..} = do
           runActions stackName PostDeploy $ stackSpecActions spec
           when sdoClean $ awsCloudFormationDeleteAllChangeSets stackName
 
+  when sdoRemovals $ do
+    removed <- inferRemovedStacks
+    traverse_ (deleteRemovedStack sdoDeployConfirmation) removed
+
+deleteRemovedStack
+  :: ( MonadMask m
+     , MonadResource m
+     , MonadLogger m
+     , MonadReader env m
+     , HasLogger env
+     , HasAwsEnv env
+     )
+  => DeployConfirmation
+  -> Stack
+  -> m ()
+deleteRemovedStack confirmation stack = do
+  withThreadContext ["stack" .= stackName] $ do
+    colors <- getColorsLogger
+    pushLoggerLn $ formatRemovedStack colors FormatTTY stack
+
+    case confirmation of
+      DeployWithConfirmation -> do
+        promptContinue
+        logInfo "Deleting Stack"
+      DeployWithoutConfirmation -> pure ()
+
+    deleteStack stackName
+  where stackName = StackName $ stack ^. stack_stackName
+
 data DeployConfirmation
   = DeployWithConfirmation
   | DeployWithoutConfirmation
   deriving stock Eq
 
-handleRollbackComplete
+checkIfStackRequiresDeletion
   :: ( MonadUnliftIO m
      , MonadResource m
      , MonadLogger m
@@ -113,13 +149,14 @@ handleRollbackComplete
   => DeployConfirmation
   -> StackName
   -> m ()
-handleRollbackComplete confirmation stackName = do
+checkIfStackRequiresDeletion confirmation stackName = do
   mStack <- awsCloudFormationDescribeStackMaybe stackName
 
-  when (maybe False stackIsRollbackComplete mStack) $ do
-    logWarn
-      $ "Stack is in ROLLBACK_COMPLETE state and must be deleted before proceeding"
-      :# ["stackName" .= stackName]
+  for_ (stackStatusRequiresDeletion =<< mStack) $ \status -> do
+    logWarn $ "Stack must be deleted before proceeding" :# ["status" .= status]
+    when (status == StackStatus_ROLLBACK_FAILED)
+      $ logWarn
+          "Stack is in ROLLBACK_FAILED. This may require elevated permissions for the delete to succeed"
 
     case confirmation of
       DeployWithConfirmation -> promptContinue
@@ -127,11 +164,19 @@ handleRollbackComplete confirmation stackName = do
         logError "Refusing to delete without confirmation"
         exitFailure
 
-    result <- awsCloudFormationDeleteStack stackName
+    logInfo "Deleting Stack"
+    deleteStack stackName
 
-    case result of
-      StackDeleteSuccess -> logInfo $ prettyStackDeleteResult result :# []
-      StackDeleteFailure{} -> logWarn $ prettyStackDeleteResult result :# []
+deleteStack
+  :: (MonadResource m, MonadLogger m, MonadReader env m, HasAwsEnv env)
+  => StackName
+  -> m ()
+deleteStack stackName = do
+  result <- awsCloudFormationDeleteStack stackName
+
+  case result of
+    StackDeleteSuccess -> logInfo $ prettyStackDeleteResult result :# []
+    StackDeleteFailure{} -> logWarn $ prettyStackDeleteResult result :# []
 
 deployChangeSet
   :: ( MonadUnliftIO m
